@@ -53,7 +53,6 @@ class LifeCycle:
         (V1Statuses.RESUMING, V1Statuses.RESUMING),
         (V1Statuses.WARNING, V1Statuses.WARNING),
         (V1Statuses.UNSCHEDULABLE, V1Statuses.UNSCHEDULABLE),
-        (V1Statuses.PIPELINE_QUEUED, V1Statuses.PIPELINE_QUEUED),
         (V1Statuses.QUEUED, V1Statuses.QUEUED),
         (V1Statuses.SCHEDULED, V1Statuses.SCHEDULED),
         (V1Statuses.STARTING, V1Statuses.STARTING),
@@ -104,10 +103,6 @@ class LifeCycle:
     def is_pending(cls, status: str) -> bool:
         return status in cls.PENDING_VALUES
 
-    @classmethod
-    def is_pipeline_queued(cls, status: str) -> bool:
-        return status == V1Statuses.PIPELINE_QUEUED
-
     @classmethod
     def is_queued(cls, status: str) -> bool:
         return status == V1Statuses.QUEUED
